<?php
/**
 * Module: Blog
 * Display a list of posts
 *
 * @author 		ThemeSquard
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Blog extends SpyropressBuilderModule {

    public function __construct() {

        // Widget variable settings.
        $this->path =  get_template_directory().'/framework/builder/modules/blog';
        $this->description =esc_html__( 'Display a list of posts', 'hotelier' );
        $this->id_base = 'recent_posts';
        $this->name =esc_html__( 'Blog', 'hotelier' );
        
        //template.
        $this->templates['view'] = array( 'view' => 'view.php', 'label' =>__( 'Style One', 'hotelier' ) );
        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>__( 'Style Two', 'hotelier' ) );
        
        // Fields
        $this->fields = array(
            
            array(
                'label' =>esc_html__( 'Template', 'hotelier' ),
                'id' => 'template',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => $this->get_option_templates()
            ),
            
            array(
                'label' =>esc_html__( 'Number of items per page', 'hotelier' ),
                'id' => 'limit',
                'type' => 'range_slider',
                'std' => 6
            ),
            
            array(
                'label' =>esc_html__( 'Category', 'hotelier' ),
                'id' => 'cat',
                'type' => 'multi_select',
                'options' => spyropress_get_taxonomies( 'category' )
            ),
            
            array(
                'label' =>esc_html__( 'Number of Columns', 'hotelier' ),
                'id' => 'columns',
                'class' => 'template view section-full',
                'type' => 'range_slider',
                'std' => 3,
                'max' => 4
            ),
            
            array(
                'label' =>esc_html__('Pagination', 'hotelier'),
                'id' => 'pagination',
                'type' => 'checkbox',
                'desc' => 'Will show pagination if portfolio per page is set.',
                'options' => array(
                    'pagination' =>esc_html__('Enable pagination for the next page', 'hotelier')
                )
            )
            
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {

        // extracting info
        extract( $spyropress_args ); extract( $spyropress_instance );
        
        //Template
        $spyropress_template = isset( $spyropress_instance['template'] ) ? $spyropress_instance['template'] : '';
        
        //Required View File
        require( $this->get_view( $spyropress_template ) ); 
    }
    
    function spyropress_query( $spyropress_atts, $spyropress_content = null ) {

        $spyropress_default = array (
            'limit' => -1,
            'columns' => false,
            'row' => false,
            'pagination' => false,
            'callback' => array( $this, 'spyropress_post_generator' ),

        );

        $spyropress_atts = wp_parse_args( $spyropress_atts, $spyropress_default );

        if ( ! empty( $spyropress_atts['cat'] ) ) {
            $spyropress_atts['tax_query']['relation'] = 'OR';
            if ( ! empty( $spyropress_atts['cat'] ) ) {
                $spyropress_atts['tax_query'][] = array(
                    'taxonomy' => 'category',
                    'field' => 'slug',
                    'terms' => $spyropress_atts['cat'],
                    );

                unset( $spyropress_atts['cat'] );

            }
        }
        
         if ( $spyropress_content )
            return token_repalce( $spyropress_content, spyropress_query_generator( $spyropress_atts ) );

        return spyropress_query_generator( $spyropress_atts );

    }
    
    function spyropress_post_generator( $post_ID, $spyropress_atts ) {
                         
        return
        '<li class="'. esc_attr( $spyropress_atts['column_class'] ) .'">
            '. get_image( array( 'class' => 'img-responsive', 'echo' => false ) ) .'
			<div class="blog-detail">
				<h3>'. get_the_title() .'</h3>
				<div class="col-xs-6 col-sm-6 col-md-6 cap col-centered center-block">
					<span><img class="img-responsive" src="'. framework_assets_img() .'cap.png" alt=""></span>
				</div>
				'. spyropress_get_excerpt() .'
			</div>
			<div class="visitor">
				<span class="calender"><i class="fa fa-calendar-o"></i>'. get_the_date( 'M d, Y' ) .'</span>
				<span class="comment"><i class="fa fa-comment"></i>'. get_comments_number() .' comments</span>
			</div>
		</li>';
        
    }
    
    function spyropress_post_generator_one( $post_ID, $atts ) {
                         
        return 
        '<li class="masonry-item">
			'. get_image( array( 'class' => 'img-responsive', 'echo' => false ) ) .'
			<div class="blog-detail">
				<h3>'. get_the_title() .'</h3>
				<div class="col-xs-6 col-sm-6 col-md-6 cap col-centered center-block">
					<span><img class="img-responsive" src="'. framework_assets_img() .'cap.png" alt=""></span>
				</div>
				'. spyropress_get_excerpt() .'
			</div>
			<div class="visitor">
				<span class="calender"><i class="fa fa-calendar-o"></i>'. get_the_date( 'M d, Y' ) .'</span>
				<span class="comment"><i class="fa fa-comment"></i>'. get_comments_number() .' comments</span>
			</div>
		</li>';
        
    }
}
//Register Module Class Spyropress_Module_Blog
spyropress_builder_register_module( 'Spyropress_Module_Blog' );