<?php
/**
 * Module: Callout
 * Display a headline, (optional) image and brief text with a link.
 *
 * @author 		ThemeSquard
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Callout extends SpyropressBuilderModule {

    public function __construct() {

        // Widget variable settings.
        $this->path =  get_template_directory().'/framework/builder/modules/callout';
        $this->cssclass = 'module-callout';
        $this->description =esc_html__( 'Display custom text with a link.', 'hotelier' );
        $this->id_base = 'spyropress_callout';
        $this->name =esc_html__( 'Callout', 'hotelier' );
        
        //template.
        $this->templates['view'] = array( 'view' => 'view.php', 'label' =>__( 'Style One', 'hotelier' ) );
        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>__( 'Style Two', 'hotelier' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>__( 'Style Three', 'hotelier' ) );
        $this->templates['view-three'] = array( 'view' => 'view-three.php', 'label' =>__( 'Style Four', 'hotelier' ) );
        $this->templates['view-four'] = array( 'view' => 'view-four.php', 'label' =>__( 'Style Five', 'hotelier' ) );
        
        // Fields
        $this->fields = array(
             
             array(
                'label' =>esc_html__( 'Template', 'hotelier' ),
                'id' => 'template',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => $this->get_option_templates()
            ),
            
            array(
                'label' =>esc_html__( 'Image One', 'hotelier' ),
                'id' => 'image_one',
                'class' => 'template view view-three view-four section-full',
                'type' => 'upload'
            ),
            
            array(
                'label' =>esc_html__( 'Image Two', 'hotelier' ),
                'id' => 'image_two',
                'class' => 'template view-four section-full',
                'type' => 'upload'
            ),
            
            array(
                'label' =>esc_html__( 'Image Three', 'hotelier' ),
                'id' => 'image_three',
                'class' => 'template view-four section-full',
                'type' => 'upload'
            ),
            
            array(
                'label' =>esc_html__( 'Image Four', 'hotelier' ),
                'id' => 'image_four',
                'class' => 'template view-four section-full',
                'type' => 'upload'
            ),
            
            array(
                'label' =>esc_html__( 'Heading', 'hotelier' ),
                'id' => 'heading',
                'class' => 'template view-one view-four view-three section-full',
                'type' => 'text'
            ),
            
            array(
                'label' =>esc_html__( 'Content', 'hotelier' ),
                'id' => 'content',
                'class' => 'template view-one view-four view-two view-three section-full',
                'type' => 'textarea',
                'rows' => 5
            ),
            
            array(
                'label' =>esc_html__( 'Custom URL Text', 'hotelier' ),
                'id' => 'url_text',
                'type' => 'text'
            ),
            
            array(
                'label' =>esc_html__( 'Custom URL', 'hotelier' ),
                'id' => 'url',
                'type' => 'text'
            )
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {

        // extracting info
        extract( $spyropress_args ); extract( $spyropress_instance );
        
        //Template
        $spyropress_template = isset( $spyropress_instance['template'] ) ? $spyropress_instance['template'] : '';
        
        //Required View File
        require( $this->get_view( $spyropress_template ) ); 
    }

}
//Register Module Class Spyropress_Module_Callout
spyropress_builder_register_module( 'Spyropress_Module_Callout' );