<?php

/**
 * Module: Heading
 * Add headings into the page layout wherever needed.
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Heading extends SpyropressBuilderModule {

    public function __construct() {

        // Widget variable settings
        $this->path =  get_template_directory().'/framework/builder/modules/heading';
        $this->cssclass = 'module-heading';
        $this->description =esc_html__( 'Add headings into the page layout wherever needed.', 'hotelier' );
        $this->id_base = 'spyropress_heading';
        $this->name =esc_html__( 'Heading', 'hotelier' );

        //template.
        $this->templates['view'] = array( 'view' => 'view.php', 'label' =>__( 'Style One', 'hotelier' ) );
        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>__( 'Style Two', 'hotelier' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>__( 'Style Three', 'hotelier' ) );
        $this->templates['view-three'] = array( 'view' => 'view-three.php', 'label' =>__( 'Style Four', 'hotelier' ) );
        $this->templates['view-four'] = array( 'view' => 'view-four.php', 'label' =>__( 'Style Five', 'hotelier' ) );
        $this->templates['view-five'] = array( 'view' => 'view-five.php', 'label' =>__( 'Style Six', 'hotelier' ) );
        
        // Fields
        $this->fields = array(
            array(
                'label' =>esc_html__( 'Template', 'hotelier' ),
                'id' => 'template',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => $this->get_option_templates()
            ),
            
            array(
                'label' =>esc_html__( 'Heading Text', 'hotelier' ),
                'id' => 'heading',
                'type' => 'text',
            ),
            
            array(
                'label' =>esc_html__( 'Sub Heading Text', 'hotelier' ),
                'id' => 'sub_heading',
                'class' => 'template view view-four view-five section-full',
                'type' => 'text',
            ),

            array(
                'label' =>esc_html__( 'Content', 'hotelier' ),
                'id' => 'content',
                'class' => 'template view view-one view-four view-five view-three section-full',
                'type' => 'textarea',
                'rows' => 3
            )
            
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {

        // extracting info
        extract( $spyropress_args ); extract( $spyropress_instance );
        
        //Template
        $spyropress_template = isset( $spyropress_instance['template'] ) ? $spyropress_instance['template'] : '';
        
        //Required View File
        require( $this->get_view( $spyropress_template ) ); 
    }
}
//Register Module Class Spyropress_Module_Heading
spyropress_builder_register_module( 'Spyropress_Module_Heading' );