<?php

/**
 * Module: Info Teaser
 * Display a brief text with a link and use Image
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Info_Teaser extends SpyropressBuilderModule {

    /**
     * Constructor
     */
    public function __construct() {

        // Widget variable settings
        $this->path =  get_template_directory().'/framework/builder/modules/info-teaser';
        $this->cssclass = 'module-info-teaser';
        $this->description =esc_html__( 'Display a brief text with a link and use Image', 'hotelier' );
        $this->id_base = 'spyropress_info_teaser';
        $this->name =esc_html__( 'Info Teaser', 'hotelier' );
        
        // Fields
        $this->fields = array (
            
            array(
                'label' =>esc_html__( 'Number of Columns', 'hotelier' ),
                'id' => 'columns',
                'class' => 'template view-one section-full',
                'type' => 'range_slider',
                'std' => 3,
                'max' => 4
            ),
            
            array(
                'label' =>esc_html__( 'Info Teaser', 'hotelier' ),
                'id' => 'teasers',
                'type' => 'repeater',
                'item_title' => 'title',
                'fields' => array(
            
                        array(
                            'label' =>esc_html__( 'Title', 'hotelier' ),
                            'id' => 'title',
                            'type' => 'text'
                        ),
                        
                        array(
                            'label' =>esc_html__( 'Sub Title', 'hotelier' ),
                            'id' => 'sub_title',
                            'type' => 'text'
                        ),
                        
                        array(
                            'label' =>esc_html__( 'Image', 'hotelier' ),
                            'id' => 'image',
                            'type' => 'upload',
                        ), 
            
                        array(
                            'label' =>esc_html__( 'Content', 'hotelier' ),
                            'id' => 'content',
                            'type' => 'textarea',
                            'rows' => 6
                        ),
                        
                        array(
                            'label' =>esc_html__( 'URL/Link Setting', 'hotelier' ),
                            'type' => 'toggle'
                        ),
                
                            array(
                                'label' =>esc_html__( 'Link Text', 'hotelier' ),
                                'id' => 'url_text',
                                'type' => 'text'
                            ),
                    
                            array(
                                'label' =>esc_html__( 'URL/Hash', 'hotelier' ),
                                'id' => 'url',
                                'type' => 'text'
                            ),
                
                        array( 'type' => 'toggle_end' ),
                        
                 )
            ) 
        );
        
        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {

        // extracting info
        extract( $spyropress_args ); extract( $spyropress_instance );
        
        //Required View File
        require( $this->get_view() ); 
    }
    
    function spyropress_info_teaser_generator( $spyropress_item, $spyropress_atts ){
        
        //link button.
        $spyropress_url_text = ( $spyropress_item['url_text'] ) ? $spyropress_item['url_text'] : esc_html__( 'LEARN MORE', 'hotelier' );
        $spyropress_btn = ( $spyropress_item['url'] )? '<a href="'. esc_url( $spyropress_item['url'] ) .'" class="btn btn-default">'. esc_html( $spyropress_url_text ) .'</a>' : '';
       
        return 
        '<li class="'. esc_attr( $spyropress_atts['column_class'] ) .'">
			<div class="img">
				<img class="img-responsive img2" src="'. esc_url( $spyropress_item['image'] ). '" alt="">
				<div class="detail">
					<h4>'. esc_html( $spyropress_item['title'] ) .'</h4>
				</div>
				<div class="mask">
					<h2>'. esc_html( $spyropress_item['sub_title'] ) .'</h2>
					<p>'. esc_html( $spyropress_item['content'] ) .'</p>
					'. $spyropress_btn .'
				</div>
			</div>
		</li>';
    }

}
//Register Module Class Spyropress_Module_Info_Teaser
spyropress_builder_register_module( 'Spyropress_Module_Info_Teaser' );