<?php

/**
 * Module: Sub-Pages
 * A list of sub-page titles or excerpts.
 *
 * @author 		ThemeSquard
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Row_Options extends SpyropressBuilderModule {

    public function __construct() {

        $this->cssclass = 'row-options';
        $this->description =esc_html__( 'Set row options and styling here.', 'hotelier' );
        $this->id_base = 'spyropress_row_options';
        $this->name =esc_html__( 'Row Options', 'hotelier' );
        $this->show_custom_css = true;

        $locations = get_registered_nav_menus();
        $menus = wp_get_nav_menus();
        $menu_options = array();

        if ( isset( $locations ) && count( $locations ) > 0 && isset( $menus ) && count( $menus ) > 0 ) {
            foreach ( $menus as $menu ) {
                $menu_options[$menu->term_id] = $menu->name;
            }
        }

        // Fields
        $this->fields = array(

            array(
                'id' => 'show',
                'type' => 'checkbox',
                'options' => array(
                    '1' => '<strong>' .esc_html__( 'Disable this row temporarily', 'hotelier' ) . '</strong>'
                )
            ),

            array(
                'label' =>esc_html__( 'Section Skin', 'hotelier' ),
                'id' => 'skin',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => array(
                    'welcome' =>esc_html__( 'Welcome', 'hotelier' ),
                    'welcome-no-bottom' =>esc_html__( 'Welcome No Padding', 'hotelier' ),
                    'accomodation' =>esc_html__( 'Accomodation', 'hotelier'),
                    'room-offer' =>esc_html__( 'Room Offer', 'hotelier' ),
                    'testimonial' =>esc_html__( 'Testimonial', 'hotelier' ),
                    'main-gallery' =>esc_html__( 'Gallery', 'hotelier' ),
                    'slider-footer' =>esc_html__( 'Slider Footer', 'hotelier' ),
                    'award' =>esc_html__( 'Award', 'hotelier' ),
                    'spa-right' =>esc_html__( 'Spa Right', 'hotelier' ),
                    'spa-glance' =>esc_html__( 'Spa Glance', 'hotelier' ),
                    'spa-block' =>esc_html__( 'Spa Block', 'hotelier' ),
                    'spa-main' =>esc_html__( 'Main Block', 'hotelier' ),
                    'dining-main' =>esc_html__( 'Dining Block', 'hotelier' ),
                    'about-main' =>esc_html__( 'About Block', 'hotelier' ),
                    'location' =>esc_html__( 'Location', 'hotelier' ),
                    'business-detail' =>esc_html__( 'Business Detail', 'hotelier' ),
                    'image-panel' =>esc_html__( 'Image Panel', 'hotelier' ),
                    'spa-img-bot' =>esc_html__( 'Image Panel Two', 'hotelier' ),
                    'detail-cont' =>esc_html__( 'Detail Cont', 'hotelier' ),
                    'parallax' =>esc_html__( 'Parallax', 'hotelier' )
                )
            ),
            
            array(
                'label' =>esc_html__( 'Parallax Background', 'hotelier' ),
                'id' => 'parallax_bg',
                'class' => 'skin image-panel parallax spa-img-bot section-full',
                'type' => 'upload',
            ),
        );

        if( !empty( $menu_options ) ) {

            $this->fields[] = array(
                'label' =>esc_html__( 'OnePage Menu Builder', 'hotelier' ),
                'type' => 'sub_heading'
            );

            $this->fields[] = array(
                'label' =>esc_html__( 'Select Menu', 'hotelier' ),
                'id' => 'menu_id',
                'type' => 'select',
                'options' => $menu_options
            );

            $this->fields[] = array(
                'label' =>esc_html__( 'Menu Label', 'hotelier' ),
                'id' => 'menu_label',
                'type' => 'text'
            );
        }

        $this->create_widget();

        add_filter( 'builder_save_row_css', array( $this, 'compile_css' ), 10, 3 );
    }

    function after_validate_fields( $instance = '' ) {

        if(
            isset( $instance['menu_id'] ) && isset( $instance['menu_label'] ) &&
            !empty( $instance['menu_id'] ) && !empty( $instance['menu_label'] )
        ) {

            $key = sanitize_key( $instance['menu_label'] );
            if( isset( $instance['custom_container_id'] ) && !empty( $instance['custom_container_id'] ) )
                 $key = $instance['custom_container_id'];
            else
                $instance['custom_container_id'] = $key;
            $menu_link = '#HOME_URL#' . $key;
            
            $is_link = false;
            $menu_item_id = $menu_item_position = 0;

            $menu_items = wp_get_nav_menu_items( $instance['menu_id'] );
            foreach ( $menu_items as $menu_item ) {
                if ( $menu_item->url == $menu_link ) {
                    $menu_item_id = $menu_item->ID;
                    $menu_item_position = $menu_item->menu_order;
                    break;
                }
            }
            
            wp_update_nav_menu_item( $instance['menu_id'], $menu_item_id, array(
                'menu-item-title' => $instance['menu_label'],
                'menu-item-classes' => 'internal',
                'menu-item-url' => $menu_link,
                'menu-item-position' => $menu_item_position,
                'menu-item-status' => 'publish'
            ) );
            
            update_option( 'menu_check', true );
        }
        return $instance;
    }

    function compile_css( $row_id, $instance, $old_instance ) {

        $row_id = isset( $instance['custom_container_id'] ) ? $instance['custom_container_id'] : $row_id;
        $row_class = isset( $instance['custom_container_class'] ) ? $instance['custom_container_class'] : '';
        $insertion = '';

        // row custom css
        if ( isset( $instance['row_custom_css'] ) && $instance['row_custom_css'] ) {
            $custom_css = $instance['row_custom_css'];

            /**
             * @deprecated {this_row}
             * @version 3.10
             */
            $custom_css = str_replace( '{this_row}', '#' . $row_id, $custom_css );

            /**
             * @since 3.10
             */
            $custom_css = str_replace( '{row_id}', '#' . $row_id, $custom_css );
            $custom_css = str_replace( '{row_class}', '.' . spyropress_uglify_cssclass( $row_class ), $custom_css );

            $insertion .= $custom_css;
        }

        return $insertion;
    }
}