<?php

/**
 * Option/Settings Helper Functions
 *
 * @category Utilities
 * @package Spyropress
 *
 */

/** Option Getter and Formatter **********************/

function get_float_class( $float ) {
    
    // check for null
    if ( ! $float ) return;

    $allowed_floats = array( 'left' => 'pull-left', 'right' => 'pull-right' );

    if ( in_array( $float, array_keys( $allowed_floats ) ) )
        $float = $allowed_floats[$float];

    return $float;
}

/**
 * Row Class
 */
function get_row_class( $return = false ) {
    global $spyropress;

    if ( $return )
        return $spyropress->row_class;
    echo $spyropress->row_class;
}

/**
 * Column Class
 */
function get_column_class( $column ) {
    if( 'skt' == get_html_framework() ) return get_skeleton_col_class( $column );
    
    if( 'bs' == get_html_framework() ) return get_bootstrap_class( $column );
    
    if( 'bs3' == get_html_framework() ) return get_bootstrap3_class( $column );
    
    if( 'fd3' == get_html_framework() ) return get_foundation3_col_class( $column );
}

/**
 * Bootstrap Class
 */
function get_bootstrap_class( $column ) {

    $class = 'span12';

    switch ( $column ) {
        case 2:
            $class = 'span6';
            break;
        case 3:
            $class = 'span4';
            break;
        case 4:
            $class = 'span3';
            break;
        case 6:
            $class = 'span2';
            break;
    }

    return $class;
}

/**
 * Bootstrap Class
 */
function get_bootstrap3_class( $column ) {

    $class = 'col-md-12';

    switch ( $column ) {
        case 2:
            $class = 'col-md-6';
            break;
        case 3:
            $class = 'col-md-4';
            break;
        case 4:
            $class = 'col-md-3';
            break;
        case 6:
            $class = 'col-md-2';
            break;
    }

    return $class;
}

/**
 * Skeleton Classes
 */
function get_skeleton_col_class( $column ) {

    $class = get_skeleton_class( 16 );

    switch ( $column ) {
        case 2:
            $class = get_skeleton_class( 8 );
            break;
        case 3:
            $class = get_skeleton_class( '1/3' );
            break;
        case 4:
            $class = get_skeleton_class( 4 );
            break;
        case 8:
            $class = get_skeleton_class( 2 );
            break;
    }

    return $class;
}

function get_skeleton_class( $column ) {
    
    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns',
        13 => 'thirteen columns',
        14 => 'fourteen columns',
        15 => 'fifteen columns',
        16 => 'sixteen columns',
        '1/3' => 'one-third column',
        '2/3' => 'two-thirds column',
    );
    
    return $classes[$column];
}

function get_admin_column_class( $column ) {
    
    $class = '';
    if( 12 == get_grid_columns() ) {

        $class = 'span12';
        
        switch ( $column ) {
            case 2:
                $class = 'span6';
                break;
            case 3:
                $class = 'span4';
                break;
            case 4:
                $class = 'span3';
                break;
            case 6:
                $class = 'span2';
                break;
        }
    }
    elseif( 16 == get_grid_columns() ) {

        $class = 'span16';
        
        switch ( $column ) {
            case 2:
                $class = 'span8';
                break;
            case 3:
                $class = 'span1by3';
                break;
            case 4:
                $class = 'span4';
                break;
            case 8:
                $class = 'span2';
                break;
        }
    }
    
    return $class;
}

/**
 * Foundation3 Classes
 */

function get_foundation3_col_class( $column ) {

    $class = get_foundation3_class( 12 );

    switch ( $column ) {
        case 2:
            $class = get_foundation3_class( 6 );
            break;
        case 3:
            $class = get_foundation3_class( 4 );
            break;
        case 4:
            $class = get_foundation3_class( 3 );
            break;
        case 6:
            $class = get_foundation3_class( 2 );
            break;
    }

    return $class;
}

function get_foundation3_class( $column ) {

    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns'
    );
    
    return $classes[$column];
}

/**
 * Get HTML Framework
 */
function get_html_framework() {
    global $spyropress;
    return $spyropress->framework;
}

/**
 * Get Grid Column
 */
function get_grid_columns() {
    global $spyropress;
    return $spyropress->grid_columns;
}

/**
 * First Column Class accoring to framework
 */
function get_first_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'alpha';
    
    // Others
    return 'column_first';
}

/**
 * Last Column Class accoring to framework
 */
function get_last_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'omega';
    
    // Foundation
    if( 'fd3' == get_html_framework() ) return 'end';
    
    // Others
    return 'column_last';
}

/** Data Sources for Post Type and Taxonomies **********************/

/**
 * Buckets
 */
function spyropress_get_buckets() {
    
    $buckets = array();
    
    if ( ! post_type_exists( 'bucket' ) ) return $buckets;
    
    // get posts
    $args = array(
        'post_type' => 'bucket',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'asc'
    );
    $posts = get_posts( $args );
    if ( !empty( $posts ) ) {
        foreach ( $posts as $post ) {
            $buckets[$post->ID] = $post->post_title;
        }
    }

    return $buckets;
}

/**
 * Custom Taxonomies
 */
function spyropress_get_taxonomies( $tax = '' ) {
    
    if ( ! $tax ) return array();

    $terms = get_terms( $tax );
    $taxs = array();
    if ( !empty( $terms ) )
        foreach ( $terms as $term )
            $taxs[$term->slug] = $term->name;

    return $taxs;
}

/** Custom Data Sources ********************************************/

/**
 * jQuery Easing Options
 */
function spyropress_get_options_easing() {
    return array(
        'linear' =>esc_html__( 'linear', 'hotelier' ),
        'jswing' =>esc_html__( 'jswing', 'hotelier' ),
        'def' =>esc_html__( 'def', 'hotelier' ),
        'easeInQuad' =>esc_html__( 'easeInQuad', 'hotelier' ),
        'easeOutQuad' =>esc_html__( 'easeOutQuad', 'hotelier' ),
        'easeInOutQuad' =>esc_html__( 'easeInOutQuad', 'hotelier' ),
        'easeInCubic' =>esc_html__( 'easeInCubic', 'hotelier' ),
        'easeOutCubic' =>esc_html__( 'easeOutCubic', 'hotelier' ),
        'easeInOutCubic' =>esc_html__( 'easeInOutCubic', 'hotelier' ),
        'easeInQuart' =>esc_html__( 'easeInQuart', 'hotelier' ),
        'easeOutQuart' =>esc_html__( 'easeOutQuart', 'hotelier' ),
        'easeInOutQuart' =>esc_html__( 'easeInOutQuart', 'hotelier' ),
        'easeInQuint' =>esc_html__( 'easeInQuint', 'hotelier' ),
        'easeOutQuint' =>esc_html__( 'easeOutQuint', 'hotelier' ),
        'easeInOutQuint' =>esc_html__( 'easeInOutQuint', 'hotelier' ),
        'easeInSine' =>esc_html__( 'easeInSine', 'hotelier' ),
        'easeOutSine' =>esc_html__( 'easeOutSine', 'hotelier' ),
        'easeInOutSine' =>esc_html__( 'easeInOutSine', 'hotelier' ),
        'easeInExpo' =>esc_html__( 'easeInExpo', 'hotelier' ),
        'easeOutExpo' =>esc_html__( 'easeOutExpo', 'hotelier' ),
        'easeInOutExpo' =>esc_html__( 'easeInOutExpo', 'hotelier' ),
        'easeInCirc' =>esc_html__( 'easeInCirc', 'hotelier' ),
        'easeOutCirc' =>esc_html__( 'easeOutCirc', 'hotelier' ),
        'easeInOutCirc' =>esc_html__( 'easeInOutCirc', 'hotelier' ),
        'easeInElastic' =>esc_html__( 'easeInElastic', 'hotelier' ),
        'easeOutElastic' =>esc_html__( 'easeOutElastic', 'hotelier' ),
        'easeInOutElastic' =>esc_html__( 'easeInOutElastic', 'hotelier' ),
        'easeInBack' =>esc_html__( 'easeInBack', 'hotelier' ),
        'easeOutBack' =>esc_html__( 'easeOutBack', 'hotelier' ),
        'easeInOutBack' =>esc_html__( 'easeInOutBack', 'hotelier' ),
        'easeInBounce' =>esc_html__( 'easeInBounce', 'hotelier' ),
        'easeOutBounce' =>esc_html__( 'easeOutBounce', 'hotelier' ),
        'easeInOutBounce' =>esc_html__( 'easeInOutBounce', 'hotelier' ),
    );
}

function spyropress_get_options_float() {
    return array(
        'none' =>esc_html__( 'None', 'hotelier' ),
        'left' =>esc_html__( 'Left', 'hotelier' ),
        'right' =>esc_html__( 'Right', 'hotelier' ),
    );
}

function spyropress_get_options_link( $fields ) {
    // check for emptiness
    if ( empty( $fields ) ) $fields = array();

    return array_merge( $fields, array(
        array(
            'label' =>esc_html__( 'URL/Link Setting', 'hotelier' ),
            'type' => 'toggle'
        ),

        array(
            'label' =>esc_html__( 'Link Text', 'hotelier' ),
            'id' => 'url_text',
            'type' => 'text'
        ),

        array(
            'label' =>esc_html__( 'URL/Hash', 'hotelier' ),
            'id' => 'url',
            'type' => 'text'
        ),

        array(
            'label' =>esc_html__( 'Link to Post/Page', 'hotelier' ),
            'id' => 'link_url',
            'type' => 'custom_post',
            'post_type' => array( 'post', 'page' )
        ),

        array( 'type' => 'toggle_end' )
    ) );
}

function spyropress_get_options_fontawesome_icons(){
    
     return array(
        'fa-adjust' =>esc_html__( 'Adjust', 'hotelier' ),
        'fa-adn' =>esc_html__( 'Adn', 'hotelier' ),
        'fa-align-center' =>esc_html__( 'Align Center', 'hotelier' ),
        'fa-align-justify' =>esc_html__( 'Align Justify', 'hotelier' ),
        'fa-align-left' =>esc_html__( 'Align Left', 'hotelier' ),
        'fa-align-right' =>esc_html__( 'Align Right', 'hotelier' ),
        'fa-ambulance' =>esc_html__( 'Ambulance', 'hotelier' ),
        'fa-anchor' =>esc_html__( 'Anchor', 'hotelier' ),
        'fa-android' =>esc_html__( 'Android', 'hotelier' ),
        'fa-angellist' =>esc_html__( 'Angellist', 'hotelier' ),
        'fa-angle-double-down' =>esc_html__( 'Angle Double Down', 'hotelier' ),
        'fa-angle-double-left' =>esc_html__( 'Angle Double Left', 'hotelier' ),
        'fa-angle-double-right' =>esc_html__( 'Angle Double Right', 'hotelier' ),
        'fa-angle-double-up' =>esc_html__( 'Angle Double Up', 'hotelier' ),
        'fa-angle-down' =>esc_html__( 'Angle Down', 'hotelier' ),
        'fa-angle-left' =>esc_html__( 'Angle Left', 'hotelier' ),
        'fa-angle-right' =>esc_html__( 'Angle Right', 'hotelier' ),
        'fa-angle-up' =>esc_html__( 'Angle Up', 'hotelier' ),
        'fa-apple' =>esc_html__( 'Apple', 'hotelier' ),
        'fa-archive' =>esc_html__( 'Archive', 'hotelier' ),
        'fa-area-chart' =>esc_html__( 'Area Chart', 'hotelier' ),
        'fa-arrow-circle-down' =>esc_html__( 'Arrow Circle Down', 'hotelier' ),
        'fa-arrow-circle-left' =>esc_html__( 'Arrow Circle Left', 'hotelier' ),
        'fa-arrow-circle-o-down' =>esc_html__( 'Arrow Circle Outline Down', 'hotelier' ),
        'fa-arrow-circle-o-left' =>esc_html__( 'Arrow Circle Outline Left', 'hotelier' ),
        'fa-arrow-circle-o-right' =>esc_html__( 'Arrow Circle Outline Right', 'hotelier' ),
        'fa-arrow-circle-o-up' =>esc_html__( 'Arrow Circle Outline Up', 'hotelier' ),
        'fa-arrow-circle-right' =>esc_html__( 'Arrow Circle Right', 'hotelier' ),
        'fa-arrow-circle-up' =>esc_html__( 'Arrow Circle Up', 'hotelier' ),
        'fa-arrow-down' =>esc_html__( 'Arrow Down', 'hotelier' ),
        'fa-arrow-left' =>esc_html__( 'Arrow Left', 'hotelier' ),
        'fa-arrow-right' =>esc_html__( 'Arrow Right', 'hotelier' ),
        'fa-arrow-up' =>esc_html__( 'Arrow Up', 'hotelier' ),
        'fa-arrows-alt' =>esc_html__( 'Arrows Alt', 'hotelier' ),
        'fa-arrows-h' =>esc_html__( 'Arrows H', 'hotelier' ),
        'fa-arrows-v' =>esc_html__( 'Arrows V', 'hotelier' ),
        'fa-arrows' =>esc_html__( 'Arrows', 'hotelier' ),
        'fa-asterisk' =>esc_html__( 'Asterisk', 'hotelier' ),
        'fa-at' =>esc_html__( 'At', 'hotelier' ),
        'fa-automobile' =>esc_html__( 'Automobile', 'hotelier' ),
        'fa-backward' =>esc_html__( 'Backward', 'hotelier' ),
        'fa-ban' =>esc_html__( 'Ban', 'hotelier' ),
        'fa-bank' =>esc_html__( 'Bank', 'hotelier' ),
        'fa-bar-chart-o' =>esc_html__( 'Bar Chart Outline', 'hotelier' ),
        'fa-bar-chart' =>esc_html__( 'Bar Chart', 'hotelier' ),
        'fa-barcode' =>esc_html__( 'Barcode', 'hotelier' ),
        'fa-bars' =>esc_html__( 'Bars', 'hotelier' ),
        'fa-beer' =>esc_html__( 'Beer', 'hotelier' ),
        'fa-behance-square' =>esc_html__( 'Behance Square', 'hotelier' ),
        'fa-behance' =>esc_html__( 'Behance', 'hotelier' ),
        'fa-bell-o' =>esc_html__( 'Bell Outline', 'hotelier' ),
        'fa-bell-slash-o' =>esc_html__( 'Bell Slash Outline', 'hotelier' ),
        'fa-bell-slash' =>esc_html__( 'Bell Slash', 'hotelier' ),
        'fa-bell' =>esc_html__( 'Bell', 'hotelier' ),
        'fa-bicycle' =>esc_html__( 'Bicycle', 'hotelier' ),
        'fa-binoculars' =>esc_html__( 'Binoculars', 'hotelier' ),
        'fa-birthday-cake' =>esc_html__( 'Birthday Cake', 'hotelier' ),
        'fa-bitbucket-square' =>esc_html__( 'Bitbucket Square', 'hotelier' ),
        'fa-bitbucket' =>esc_html__( 'Bitbucket', 'hotelier' ),
        'fa-bitcoin' =>esc_html__( 'Bitcoin', 'hotelier' ),
        'fa-bold' =>esc_html__( 'Bold', 'hotelier' ),
        'fa-bolt' =>esc_html__( 'Bolt', 'hotelier' ),
        'fa-bomb' =>esc_html__( 'Bomb', 'hotelier' ),
        'fa-book' =>esc_html__( 'Book', 'hotelier' ),
        'fa-bookmark-o' =>esc_html__( 'Bookmark Outline', 'hotelier' ),
        'fa-bookmark' =>esc_html__( 'Bookmark', 'hotelier' ),
        'fa-briefcase' =>esc_html__( 'Briefcase', 'hotelier' ),
        'fa-btc' =>esc_html__( 'Btc', 'hotelier' ),
        'fa-bug' =>esc_html__( 'Bug', 'hotelier' ),
        'fa-building-o' =>esc_html__( 'Building Outline', 'hotelier' ),
        'fa-building' =>esc_html__( 'Building', 'hotelier' ),
        'fa-bullhorn' =>esc_html__( 'Bullhorn', 'hotelier' ),
        'fa-bullseye' =>esc_html__( 'Bullseye', 'hotelier' ),
        'fa-bus' =>esc_html__( 'Bus', 'hotelier' ),
        'fa-cc-amex' =>esc_html__( 'CC Amex', 'hotelier' ),
        'fa-cc-discover' =>esc_html__( 'CC Discover', 'hotelier' ),
        'fa-cc-mastercard' =>esc_html__( 'CC Mastercard', 'hotelier' ),
        'fa-cc-paypal' =>esc_html__( 'CC Paypal', 'hotelier' ),
        'fa-cc-stripe' =>esc_html__( 'CC Stripe', 'hotelier' ),
        'fa-cc-visa' =>esc_html__( 'CC Visa', 'hotelier' ),
        'fa-cab' =>esc_html__( 'Cab', 'hotelier' ),
        'fa-calculator' =>esc_html__( 'Calculator', 'hotelier' ),
        'fa-calendar-o' =>esc_html__( 'Calendar Outline', 'hotelier' ),
        'fa-calendar' =>esc_html__( 'Calendar', 'hotelier' ),
        'fa-camera-retro' =>esc_html__( 'Camera Retro', 'hotelier' ),
        'fa-camera' =>esc_html__( 'Camera', 'hotelier' ),
        'fa-car' =>esc_html__( 'Car', 'hotelier' ),
        'fa-caret-down' =>esc_html__( 'Caret Down', 'hotelier' ),
        'fa-caret-left' =>esc_html__( 'Caret Left', 'hotelier' ),
        'fa-caret-right' =>esc_html__( 'Caret Right', 'hotelier' ),
        'fa-caret-square-o-down' =>esc_html__( 'Caret Square Outline Down', 'hotelier' ),
        'fa-caret-square-o-left' =>esc_html__( 'Caret Square Outline Left', 'hotelier' ),
        'fa-caret-square-o-right' =>esc_html__( 'Caret Square Outline Right', 'hotelier' ),
        'fa-caret-square-o-up' =>esc_html__( 'Caret Square Outline Up', 'hotelier' ),
        'fa-caret-up' =>esc_html__( 'Caret Up', 'hotelier' ),
        'fa-cc' =>esc_html__( 'Cc', 'hotelier' ),
        'fa-certificate' =>esc_html__( 'Certificate', 'hotelier' ),
        'fa-chain-broken' =>esc_html__( 'Chain Broken', 'hotelier' ),
        'fa-chain' =>esc_html__( 'Chain', 'hotelier' ),
        'fa-check-circle-o' =>esc_html__( 'Check Circle Outline', 'hotelier' ),
        'fa-check-circle' =>esc_html__( 'Check Circle', 'hotelier' ),
        'fa-check-square-o' =>esc_html__( 'Check Square Outline', 'hotelier' ),
        'fa-check-square' =>esc_html__( 'Check Square', 'hotelier' ),
        'fa-check' =>esc_html__( 'Check', 'hotelier' ),
        'fa-chevron-circle-down' =>esc_html__( 'Chevron Circle Down', 'hotelier' ),
        'fa-chevron-circle-left' =>esc_html__( 'Chevron Circle Left', 'hotelier' ),
        'fa-chevron-circle-right' =>esc_html__( 'Chevron Circle Right', 'hotelier' ),
        'fa-chevron-circle-up' =>esc_html__( 'Chevron Circle Up', 'hotelier' ),
        'fa-chevron-down' =>esc_html__( 'Chevron Down', 'hotelier' ),
        'fa-chevron-left' =>esc_html__( 'Chevron Left', 'hotelier' ),
        'fa-chevron-right' =>esc_html__( 'Chevron Right', 'hotelier' ),
        'fa-chevron-up' =>esc_html__( 'Chevron Up', 'hotelier' ),
        'fa-child' =>esc_html__( 'Child', 'hotelier' ),
        'fa-circle-o-notch' =>esc_html__( 'Circle Outline Notch', 'hotelier' ),
        'fa-circle-o' =>esc_html__( 'Circle Outline', 'hotelier' ),
        'fa-circle-thin' =>esc_html__( 'Circle Thin', 'hotelier' ),
        'fa-circle' =>esc_html__( 'Circle', 'hotelier' ),
        'fa-clipboard' =>esc_html__( 'Clipboard', 'hotelier' ),
        'fa-clock-o' =>esc_html__( 'Clock Outline', 'hotelier' ),
        'fa-close' =>esc_html__( 'Close', 'hotelier' ),
        'fa-cloud-download' =>esc_html__( 'Cloud Download', 'hotelier' ),
        'fa-cloud-upload' =>esc_html__( 'Cloud Upload', 'hotelier' ),
        'fa-cloud' =>esc_html__( 'Cloud', 'hotelier' ),
        'fa-cny' =>esc_html__( 'Cny', 'hotelier' ),
        'fa-code-fork' =>esc_html__( 'Code Fork', 'hotelier' ),
        'fa-code' =>esc_html__( 'Code', 'hotelier' ),
        'fa-codepen' =>esc_html__( 'Codepen', 'hotelier' ),
        'fa-coffee' =>esc_html__( 'Coffee', 'hotelier' ),
        'fa-cog' =>esc_html__( 'Cog', 'hotelier' ),
        'fa-cogs' =>esc_html__( 'Cogs', 'hotelier' ),
        'fa-columns' =>esc_html__( 'Columns', 'hotelier' ),
        'fa-comment-o' =>esc_html__( 'Comment Outline', 'hotelier' ),
        'fa-comment' =>esc_html__( 'Comment', 'hotelier' ),
        'fa-comments-o' =>esc_html__( 'Comments Outline', 'hotelier' ),
        'fa-comments' =>esc_html__( 'Comments', 'hotelier' ),
        'fa-compass' =>esc_html__( 'Compass', 'hotelier' ),
        'fa-compress' =>esc_html__( 'Compress', 'hotelier' ),
        'fa-copy' =>esc_html__( 'Copy', 'hotelier' ),
        'fa-copyright' =>esc_html__( 'Copyright', 'hotelier' ),
        'fa-credit-card' =>esc_html__( 'Credit Card', 'hotelier' ),
        'fa-crop' =>esc_html__( 'Crop', 'hotelier' ),
        'fa-crosshairs' =>esc_html__( 'Crosshairs', 'hotelier' ),
        'fa-css3' =>esc_html__( 'Css3', 'hotelier' ),
        'fa-cube' =>esc_html__( 'Cube', 'hotelier' ),
        'fa-cubes' =>esc_html__( 'Cubes', 'hotelier' ),
        'fa-cut' =>esc_html__( 'Cut', 'hotelier' ),
        'fa-cutlery' =>esc_html__( 'Cutlery', 'hotelier' ),
        'fa-dashboard' =>esc_html__( 'Dashboard', 'hotelier' ),
        'fa-database' =>esc_html__( 'Database', 'hotelier' ),
        'fa-dedent' =>esc_html__( 'Dedent', 'hotelier' ),
        'fa-delicious' =>esc_html__( 'Delicious', 'hotelier' ),
        'fa-desktop' =>esc_html__( 'Desktop', 'hotelier' ),
        'fa-deviantart' =>esc_html__( 'Deviantart', 'hotelier' ),
        'fa-digg' =>esc_html__( 'Digg', 'hotelier' ),
        'fa-dollar' =>esc_html__( 'Dollar', 'hotelier' ),
        'fa-dot-circle-o' =>esc_html__( 'Dot Circle Outline', 'hotelier' ),
        'fa-download' =>esc_html__( 'Download', 'hotelier' ),
        'fa-dribbble' =>esc_html__( 'Dribbble', 'hotelier' ),
        'fa-dropbox' =>esc_html__( 'Dropbox', 'hotelier' ),
        'fa-drupal' =>esc_html__( 'Drupal', 'hotelier' ),
        'fa-edit' =>esc_html__( 'Edit', 'hotelier' ),
        'fa-eject' =>esc_html__( 'Eject', 'hotelier' ),
        'fa-ellipsis-h' =>esc_html__( 'Ellipsis H', 'hotelier' ),
        'fa-ellipsis-v' =>esc_html__( 'Ellipsis V', 'hotelier' ),
        'fa-empire' =>esc_html__( 'Empire', 'hotelier' ),
        'fa-envelope-o' =>esc_html__( 'Envelope Outline', 'hotelier' ),
        'fa-envelope-square' =>esc_html__( 'Envelope Square', 'hotelier' ),
        'fa-envelope' =>esc_html__( 'Envelope', 'hotelier' ),
        'fa-eraser' =>esc_html__( 'Eraser', 'hotelier' ),
        'fa-eur' =>esc_html__( 'Eur', 'hotelier' ),
        'fa-euro' =>esc_html__( 'Euro', 'hotelier' ),
        'fa-exchange' =>esc_html__( 'Exchange', 'hotelier' ),
        'fa-exclamation-circle' =>esc_html__( 'Exclamation Circle', 'hotelier' ),
        'fa-exclamation-triangle' =>esc_html__( 'Exclamation Triangle', 'hotelier' ),
        'fa-exclamation' =>esc_html__( 'Exclamation', 'hotelier' ),
        'fa-expand' =>esc_html__( 'Expand', 'hotelier' ),
        'fa-external-link-square' =>esc_html__( 'External Link Square', 'hotelier' ),
        'fa-external-link' =>esc_html__( 'External Link', 'hotelier' ),
        'fa-eye-slash' =>esc_html__( 'Eye Slash', 'hotelier' ),
        'fa-eye' =>esc_html__( 'Eye', 'hotelier' ),
        'fa-eyedropper' =>esc_html__( 'Eyedropper', 'hotelier' ),
        'fa-facebook-square' =>esc_html__( 'Facebook Square', 'hotelier' ),
        'fa-facebook' =>esc_html__( 'Facebook', 'hotelier' ),
        'fa-fast-backward' =>esc_html__( 'Fast Backward', 'hotelier' ),
        'fa-fast-forward' =>esc_html__( 'Fast Forward', 'hotelier' ),
        'fa-fax' =>esc_html__( 'Fax', 'hotelier' ),
        'fa-female' =>esc_html__( 'Female', 'hotelier' ),
        'fa-fighter-jet' =>esc_html__( 'Fighter Jet', 'hotelier' ),
        'fa-file-archive-o' =>esc_html__( 'File Archive Outline', 'hotelier' ),
        'fa-file-audio-o' =>esc_html__( 'File Audio Outline', 'hotelier' ),
        'fa-file-code-o' =>esc_html__( 'File Code Outline', 'hotelier' ),
        'fa-file-excel-o' =>esc_html__( 'File Excel Outline', 'hotelier' ),
        'fa-file-image-o' =>esc_html__( 'File Image Outline', 'hotelier' ),
        'fa-file-movie-o' =>esc_html__( 'File Movie Outline', 'hotelier' ),
        'fa-file-o' =>esc_html__( 'File Outline', 'hotelier' ),
        'fa-file-pdf-o' =>esc_html__( 'File Pdf Outline', 'hotelier' ),
        'fa-file-photo-o' =>esc_html__( 'File Photo Outline', 'hotelier' ),
        'fa-file-picture-o' =>esc_html__( 'File Picture Outline', 'hotelier' ),
        'fa-file-powerpoint-o' =>esc_html__( 'File Powerpoint Outline', 'hotelier' ),
        'fa-file-sound-o' =>esc_html__( 'File Sound Outline', 'hotelier' ),
        'fa-file-text-o' =>esc_html__( 'File Text Outline', 'hotelier' ),
        'fa-file-text' =>esc_html__( 'File Text', 'hotelier' ),
        'fa-file-video-o' =>esc_html__( 'File Video Outline', 'hotelier' ),
        'fa-file-word-o' =>esc_html__( 'File Word Outline', 'hotelier' ),
        'fa-file-zip-o' =>esc_html__( 'File Zip Outline', 'hotelier' ),
        'fa-file' =>esc_html__( 'File', 'hotelier' ),
        'fa-files-o' =>esc_html__( 'Files Outline', 'hotelier' ),
        'fa-film' =>esc_html__( 'Film', 'hotelier' ),
        'fa-filter' =>esc_html__( 'Filter', 'hotelier' ),
        'fa-fire-extinguisher' =>esc_html__( 'Fire Extinguisher', 'hotelier' ),
        'fa-fire' =>esc_html__( 'Fire', 'hotelier' ),
        'fa-flag-checkered' =>esc_html__( 'Flag Checkered', 'hotelier' ),
        'fa-flag-o' =>esc_html__( 'Flag Outline', 'hotelier' ),
        'fa-flag' =>esc_html__( 'Flag', 'hotelier' ),
        'fa-flash' =>esc_html__( 'Flash', 'hotelier' ),
        'fa-flask' =>esc_html__( 'Flask', 'hotelier' ),
        'fa-flickr' =>esc_html__( 'Flickr', 'hotelier' ),
        'fa-floppy-o' =>esc_html__( 'Floppy Outline', 'hotelier' ),
        'fa-folder-o' =>esc_html__( 'Folder Outline', 'hotelier' ),
        'fa-folder-open-o' =>esc_html__( 'Folder Outlinepen Outline', 'hotelier' ),
        'fa-folder-open' =>esc_html__( 'Folder Outlinepen', 'hotelier' ),
        'fa-folder' =>esc_html__( 'Folder', 'hotelier' ),
        'fa-font' =>esc_html__( 'Font', 'hotelier' ),
        'fa-forward' =>esc_html__( 'Forward', 'hotelier' ),
        'fa-foursquare' =>esc_html__( 'Foursquare', 'hotelier' ),
        'fa-frown-o' =>esc_html__( 'Frown Outline', 'hotelier' ),
        'fa-futbol-o' =>esc_html__( 'Futbol Outline', 'hotelier' ),
        'fa-gamepad' =>esc_html__( 'Gamepad', 'hotelier' ),
        'fa-gavel' =>esc_html__( 'Gavel', 'hotelier' ),
        'fa-gbp' =>esc_html__( 'Gbp', 'hotelier' ),
        'fa-ge' =>esc_html__( 'Ge', 'hotelier' ),
        'fa-gear' =>esc_html__( 'Gear', 'hotelier' ),
        'fa-gears' =>esc_html__( 'Gears', 'hotelier' ),
        'fa-gift' =>esc_html__( 'Gift', 'hotelier' ),
        'fa-git-square' =>esc_html__( 'Git Square', 'hotelier' ),
        'fa-git' =>esc_html__( 'Git', 'hotelier' ),
        'fa-github-alt' =>esc_html__( 'Github Alt', 'hotelier' ),
        'fa-github-square' =>esc_html__( 'Github Square', 'hotelier' ),
        'fa-github' =>esc_html__( 'Github', 'hotelier' ),
        'fa-gittip' =>esc_html__( 'Gittip', 'hotelier' ),
        'fa-glass' =>esc_html__( 'Glass', 'hotelier' ),
        'fa-globe' =>esc_html__( 'Globe', 'hotelier' ),
        'fa-google-plus-square' =>esc_html__( 'Google Plus Square', 'hotelier' ),
        'fa-google-plus' =>esc_html__( 'Google Plus', 'hotelier' ),
        'fa-google-wallet' =>esc_html__( 'Google Wallet', 'hotelier' ),
        'fa-google' =>esc_html__( 'Google', 'hotelier' ),
        'fa-graduation-cap' =>esc_html__( 'Graduation Cap', 'hotelier' ),
        'fa-group' =>esc_html__( 'Group', 'hotelier' ),
        'fa-h-square' =>esc_html__( 'H Square', 'hotelier' ),
        'fa-hacker-news' =>esc_html__( 'Hacker News', 'hotelier' ),
        'fa-hand-o-down' =>esc_html__( 'Hand Outline Down', 'hotelier' ),
        'fa-hand-o-left' =>esc_html__( 'Hand Outline Left', 'hotelier' ),
        'fa-hand-o-right' =>esc_html__( 'Hand Outline Right', 'hotelier' ),
        'fa-hand-o-up' =>esc_html__( 'Hand Outline Up', 'hotelier' ),
        'fa-hdd-o' =>esc_html__( 'Hdd Outline', 'hotelier' ),
        'fa-header' =>esc_html__( 'Header', 'hotelier' ),
        'fa-headphones' =>esc_html__( 'Headphones', 'hotelier' ),
        'fa-heart-o' =>esc_html__( 'Heart Outline', 'hotelier' ),
        'fa-heart' =>esc_html__( 'Heart', 'hotelier' ),
        'fa-history' =>esc_html__( 'History', 'hotelier' ),
        'fa-home' =>esc_html__( 'Home', 'hotelier' ),
        'fa-hospital-o' =>esc_html__( 'Hospital Outline', 'hotelier' ),
        'fa-html5' =>esc_html__( 'Html5', 'hotelier' ),
        'fa-ils' =>esc_html__( 'Ils', 'hotelier' ),
        'fa-image' =>esc_html__( 'Image', 'hotelier' ),
        'fa-inbox' =>esc_html__( 'Inbox', 'hotelier' ),
        'fa-indent' =>esc_html__( 'Indent', 'hotelier' ),
        'fa-info-circle' =>esc_html__( 'Info Circle', 'hotelier' ),
        'fa-info' =>esc_html__( 'Info', 'hotelier' ),
        'fa-inr' =>esc_html__( 'Inr', 'hotelier' ),
        'fa-instagram' =>esc_html__( 'Instagram', 'hotelier' ),
        'fa-institution' =>esc_html__( 'Institution', 'hotelier' ),
        'fa-ioxhost' =>esc_html__( 'Ioxhost', 'hotelier' ),
        'fa-italic' =>esc_html__( 'Italic', 'hotelier' ),
        'fa-joomla' =>esc_html__( 'Joomla', 'hotelier' ),
        'fa-jpy' =>esc_html__( 'Jpy', 'hotelier' ),
        'fa-jsfiddle' =>esc_html__( 'Jsfiddle', 'hotelier' ),
        'fa-key' =>esc_html__( 'Key', 'hotelier' ),
        'fa-keyboard-o' =>esc_html__( 'Keyboard Outline', 'hotelier' ),
        'fa-krw' =>esc_html__( 'Krw', 'hotelier' ),
        'fa-language' =>esc_html__( 'Language', 'hotelier' ),
        'fa-laptop' =>esc_html__( 'Laptop', 'hotelier' ),
        'fa-lastfm-square' =>esc_html__( 'Lastfm Square', 'hotelier' ),
        'fa-lastfm' =>esc_html__( 'Lastfm', 'hotelier' ),
        'fa-leaf' =>esc_html__( 'Leaf', 'hotelier' ),
        'fa-legal' =>esc_html__( 'Legal', 'hotelier' ),
        'fa-lemon-o' =>esc_html__( 'Lemon Outline', 'hotelier' ),
        'fa-level-down' =>esc_html__( 'Level Down', 'hotelier' ),
        'fa-level-up' =>esc_html__( 'Level Up', 'hotelier' ),
        'fa-life-bouy' =>esc_html__( 'Life Bouy', 'hotelier' ),
        'fa-life-buoy' =>esc_html__( 'Life Buoy', 'hotelier' ),
        'fa-life-ring' =>esc_html__( 'Life Ring', 'hotelier' ),
        'fa-life-saver' =>esc_html__( 'Life Saver', 'hotelier' ),
        'fa-lightbulb-o' =>esc_html__( 'Lightbulb Outline', 'hotelier' ),
        'fa-line-chart' =>esc_html__( 'Line Chart', 'hotelier' ),
        'fa-link' =>esc_html__( 'Link', 'hotelier' ),
        'fa-linkedin-square' =>esc_html__( 'Linkedin Square', 'hotelier' ),
        'fa-linkedin' =>esc_html__( 'Linkedin', 'hotelier' ),
        'fa-linux' =>esc_html__( 'Linux', 'hotelier' ),
        'fa-list-alt' =>esc_html__( 'List Alt', 'hotelier' ),
        'fa-list-ol' =>esc_html__( 'List Outlinel', 'hotelier' ),
        'fa-list-ul' =>esc_html__( 'List Ul', 'hotelier' ),
        'fa-list' =>esc_html__( 'List', 'hotelier' ),
        'fa-location-arrow' =>esc_html__( 'Location Arrow', 'hotelier' ),
        'fa-lock' =>esc_html__( 'Lock', 'hotelier' ),
        'fa-long-arrow-down' =>esc_html__( 'Long Arrow Down', 'hotelier' ),
        'fa-long-arrow-left' =>esc_html__( 'Long Arrow Left', 'hotelier' ),
        'fa-long-arrow-right' =>esc_html__( 'Long Arrow Right', 'hotelier' ),
        'fa-long-arrow-up' =>esc_html__( 'Long Arrow Up', 'hotelier' ),
        'fa-magic' =>esc_html__( 'Magic', 'hotelier' ),
        'fa-magnet' =>esc_html__( 'Magnet', 'hotelier' ),
        'fa-mail-forward' =>esc_html__( 'Mail Forward', 'hotelier' ),
        'fa-mail-reply-all' =>esc_html__( 'Mail Reply All', 'hotelier' ),
        'fa-mail-reply' =>esc_html__( 'Mail Reply', 'hotelier' ),
        'fa-male' =>esc_html__( 'Male', 'hotelier' ),
        'fa-map-marker' =>esc_html__( 'Map Marker', 'hotelier' ),
        'fa-maxcdn' =>esc_html__( 'Maxcdn', 'hotelier' ),
        'fa-meanpath' =>esc_html__( 'Meanpath', 'hotelier' ),
        'fa-medkit' =>esc_html__( 'Medkit', 'hotelier' ),
        'fa-meh-o' =>esc_html__( 'Meh Outline', 'hotelier' ),
        'fa-microphone-slash' =>esc_html__( 'Microphone Slash', 'hotelier' ),
        'fa-microphone' =>esc_html__( 'Microphone', 'hotelier' ),
        'fa-minus-circle' =>esc_html__( 'Minus Circle', 'hotelier' ),
        'fa-minus-square-o' =>esc_html__( 'Minus Square Outline', 'hotelier' ),
        'fa-minus-square' =>esc_html__( 'Minus Square', 'hotelier' ),
        'fa-minus' =>esc_html__( 'Minus', 'hotelier' ),
        'fa-mobile-phone' =>esc_html__( 'Mobile Phone', 'hotelier' ),
        'fa-mobile' =>esc_html__( 'Mobile', 'hotelier' ),
        'fa-money' =>esc_html__( 'Money', 'hotelier' ),
        'fa-moon-o' =>esc_html__( 'Moon Outline', 'hotelier' ),
        'fa-mortar-board' =>esc_html__( 'Mortar Board', 'hotelier' ),
        'fa-music' =>esc_html__( 'Music', 'hotelier' ),
        'fa-navicon' =>esc_html__( 'Navicon', 'hotelier' ),
        'fa-newspaper-o' =>esc_html__( 'Newspaper Outline', 'hotelier' ),
        'fa-openid' =>esc_html__( 'Openid', 'hotelier' ),
        'fa-outdent' =>esc_html__( 'Outdent', 'hotelier' ),
        'fa-pagelines' =>esc_html__( 'Pagelines', 'hotelier' ),
        'fa-paint-brush' =>esc_html__( 'Paint Brush', 'hotelier' ),
        'fa-paper-plane-o' =>esc_html__( 'Paper Plane Outline', 'hotelier' ),
        'fa-paper-plane' =>esc_html__( 'Paper Plane', 'hotelier' ),
        'fa-paperclip' =>esc_html__( 'Paperclip', 'hotelier' ),
        'fa-paragraph' =>esc_html__( 'Paragraph', 'hotelier' ),
        'fa-paste' =>esc_html__( 'Paste', 'hotelier' ),
        'fa-pause' =>esc_html__( 'Pause', 'hotelier' ),
        'fa-paw' =>esc_html__( 'Paw', 'hotelier' ),
        'fa-paypal' =>esc_html__( 'Paypal', 'hotelier' ),
        'fa-pencil-square-o' =>esc_html__( 'Pencil Square Outline', 'hotelier' ),
        'fa-pencil-square' =>esc_html__( 'Pencil Square', 'hotelier' ),
        'fa-pencil' =>esc_html__( 'Pencil', 'hotelier' ),
        'fa-phone-square' =>esc_html__( 'Phone Square', 'hotelier' ),
        'fa-phone' =>esc_html__( 'Phone', 'hotelier' ),
        'fa-photo' =>esc_html__( 'Photo', 'hotelier' ),
        'fa-picture-o' =>esc_html__( 'Picture Outline', 'hotelier' ),
        'fa-pie-chart' =>esc_html__( 'Pie Chart', 'hotelier' ),
        'fa-pied-piper-alt' =>esc_html__( 'Pied Piper Alt', 'hotelier' ),
        'fa-pied-piper' =>esc_html__( 'Pied Piper', 'hotelier' ),
        'fa-pinterest-square' =>esc_html__( 'Pinterest Square', 'hotelier' ),
        'fa-pinterest' =>esc_html__( 'Pinterest', 'hotelier' ),
        'fa-plane' =>esc_html__( 'Plane', 'hotelier' ),
        'fa-play-circle-o' =>esc_html__( 'Play Circle Outline', 'hotelier' ),
        'fa-play-circle' =>esc_html__( 'Play Circle', 'hotelier' ),
        'fa-play' =>esc_html__( 'Play', 'hotelier' ),
        'fa-plug' =>esc_html__( 'Plug', 'hotelier' ),
        'fa-plus-circle' =>esc_html__( 'Plus Circle', 'hotelier' ),
        'fa-plus-square-o' =>esc_html__( 'Plus Square Outline', 'hotelier' ),
        'fa-plus-square' =>esc_html__( 'Plus Square', 'hotelier' ),
        'fa-plus' =>esc_html__( 'Plus', 'hotelier' ),
        'fa-power-off' =>esc_html__( 'Power Outlineff', 'hotelier' ),
        'fa-print' =>esc_html__( 'Print', 'hotelier' ),
        'fa-puzzle-piece' =>esc_html__( 'Puzzle Piece', 'hotelier' ),
        'fa-qq' =>esc_html__( 'Qq', 'hotelier' ),
        'fa-qrcode' =>esc_html__( 'Qrcode', 'hotelier' ),
        'fa-question-circle' =>esc_html__( 'Question Circle', 'hotelier' ),
        'fa-question' =>esc_html__( 'Question', 'hotelier' ),
        'fa-quote-left' =>esc_html__( 'Quote Left', 'hotelier' ),
        'fa-quote-right' =>esc_html__( 'Quote Right', 'hotelier' ),
        'fa-ra' =>esc_html__( 'Ra', 'hotelier' ),
        'fa-random' =>esc_html__( 'Random', 'hotelier' ),
        'fa-rebel' =>esc_html__( 'Rebel', 'hotelier' ),
        'fa-recycle' =>esc_html__( 'Recycle', 'hotelier' ),
        'fa-reddit-square' =>esc_html__( 'Reddit Square', 'hotelier' ),
        'fa-reddit' =>esc_html__( 'Reddit', 'hotelier' ),
        'fa-refresh' =>esc_html__( 'Refresh', 'hotelier' ),
        'fa-remove' =>esc_html__( 'Remove', 'hotelier' ),
        'fa-renren' =>esc_html__( 'Renren', 'hotelier' ),
        'fa-reorder' =>esc_html__( 'Reorder', 'hotelier' ),
        'fa-repeat' =>esc_html__( 'Repeat', 'hotelier' ),
        'fa-reply-all' =>esc_html__( 'Reply All', 'hotelier' ),
        'fa-reply' =>esc_html__( 'Reply', 'hotelier' ),
        'fa-retweet' =>esc_html__( 'Retweet', 'hotelier' ),
        'fa-rmb' =>esc_html__( 'Rmb', 'hotelier' ),
        'fa-road' =>esc_html__( 'Road', 'hotelier' ),
        'fa-rocket' =>esc_html__( 'Rocket', 'hotelier' ),
        'fa-rotate-left' =>esc_html__( 'Rotate Left', 'hotelier' ),
        'fa-rotate-right' =>esc_html__( 'Rotate Right', 'hotelier' ),
        'fa-rouble' =>esc_html__( 'Rouble', 'hotelier' ),
        'fa-rss-square' =>esc_html__( 'Rss Square', 'hotelier' ),
        'fa-rss' =>esc_html__( 'Rss', 'hotelier' ),
        'fa-rub' =>esc_html__( 'Rub', 'hotelier' ),
        'fa-ruble' =>esc_html__( 'Ruble', 'hotelier' ),
        'fa-rupee' =>esc_html__( 'Rupee', 'hotelier' ),
        'fa-save' =>esc_html__( 'Save', 'hotelier' ),
        'fa-scissors' =>esc_html__( 'Scissors', 'hotelier' ),
        'fa-search-minus' =>esc_html__( 'Search Minus', 'hotelier' ),
        'fa-search-plus' =>esc_html__( 'Search Plus', 'hotelier' ),
        'fa-search' =>esc_html__( 'Search', 'hotelier' ),
        'fa-send-o' =>esc_html__( 'Send Outline', 'hotelier' ),
        'fa-send' =>esc_html__( 'Send', 'hotelier' ),
        'fa-share-alt-square' =>esc_html__( 'Share Alt Square', 'hotelier' ),
        'fa-share-alt' =>esc_html__( 'Share Alt', 'hotelier' ),
        'fa-share-square-o' =>esc_html__( 'Share Square Outline', 'hotelier' ),
        'fa-share-square' =>esc_html__( 'Share Square', 'hotelier' ),
        'fa-share' =>esc_html__( 'Share', 'hotelier' ),
        'fa-shekel' =>esc_html__( 'Shekel', 'hotelier' ),
        'fa-sheqel' =>esc_html__( 'Sheqel', 'hotelier' ),
        'fa-shield' =>esc_html__( 'Shield', 'hotelier' ),
        'fa-shopping-cart' =>esc_html__( 'Shopping Cart', 'hotelier' ),
        'fa-sign-in' =>esc_html__( 'Sign In', 'hotelier' ),
        'fa-sign-out' =>esc_html__( 'Sign Outlineut', 'hotelier' ),
        'fa-signal' =>esc_html__( 'Signal', 'hotelier' ),
        'fa-sitemap' =>esc_html__( 'Sitemap', 'hotelier' ),
        'fa-skype' =>esc_html__( 'Skype', 'hotelier' ),
        'fa-slack' =>esc_html__( 'Slack', 'hotelier' ),
        'fa-sliders' =>esc_html__( 'Sliders', 'hotelier' ),
        'fa-slideshare' =>esc_html__( 'Slideshare', 'hotelier' ),
        'fa-smile-o' =>esc_html__( 'Smile Outline', 'hotelier' ),
        'fa-soccer-ball-o' =>esc_html__( 'Soccer Ball Outline', 'hotelier' ),
        'fa-sort-alpha-asc' =>esc_html__( 'Sort Alpha Asc', 'hotelier' ),
        'fa-sort-alpha-desc' =>esc_html__( 'Sort Alpha Desc', 'hotelier' ),
        'fa-sort-amount-asc' =>esc_html__( 'Sort Amount Asc', 'hotelier' ),
        'fa-sort-amount-desc' =>esc_html__( 'Sort Amount Desc', 'hotelier' ),
        'fa-sort-asc' =>esc_html__( 'Sort Asc', 'hotelier' ),
        'fa-sort-desc' =>esc_html__( 'Sort Desc', 'hotelier' ),
        'fa-sort-down' =>esc_html__( 'Sort Down', 'hotelier' ),
        'fa-sort-numeric-asc' =>esc_html__( 'Sort Numeric Asc', 'hotelier' ),
        'fa-sort-numeric-desc' =>esc_html__( 'Sort Numeric Desc', 'hotelier' ),
        'fa-sort-up' =>esc_html__( 'Sort Up', 'hotelier' ),
        'fa-sort' =>esc_html__( 'Sort', 'hotelier' ),
        'fa-soundcloud' =>esc_html__( 'Soundcloud', 'hotelier' ),
        'fa-space-shuttle' =>esc_html__( 'Space Shuttle', 'hotelier' ),
        'fa-spinner' =>esc_html__( 'Spinner', 'hotelier' ),
        'fa-spoon' =>esc_html__( 'Spoon', 'hotelier' ),
        'fa-spotify' =>esc_html__( 'Spotify', 'hotelier' ),
        'fa-square-o' =>esc_html__( 'Square Outline', 'hotelier' ),
        'fa-square' =>esc_html__( 'Square', 'hotelier' ),
        'fa-stack-exchange' =>esc_html__( 'Stack Exchange', 'hotelier' ),
        'fa-stack-overflow' =>esc_html__( 'Stack Outlineverflow', 'hotelier' ),
        'fa-star-half-empty' =>esc_html__( 'Star Half Empty', 'hotelier' ),
        'fa-star-half-full' =>esc_html__( 'Star Half Full', 'hotelier' ),
        'fa-star-half-o' =>esc_html__( 'Star Half Outline', 'hotelier' ),
        'fa-star-half' =>esc_html__( 'Star Half', 'hotelier' ),
        'fa-star-o' =>esc_html__( 'Star Outline', 'hotelier' ),
        'fa-star' =>esc_html__( 'Star', 'hotelier' ),
        'fa-steam-square' =>esc_html__( 'Steam Square', 'hotelier' ),
        'fa-steam' =>esc_html__( 'Steam', 'hotelier' ),
        'fa-step-backward' =>esc_html__( 'Step Backward', 'hotelier' ),
        'fa-step-forward' =>esc_html__( 'Step Forward', 'hotelier' ),
        'fa-stethoscope' =>esc_html__( 'Stethoscope', 'hotelier' ),
        'fa-stop' =>esc_html__( 'Stop', 'hotelier' ),
        'fa-strikethrough' =>esc_html__( 'Strikethrough', 'hotelier' ),
        'fa-stumbleupon-circle' =>esc_html__( 'Stumbleupon Circle', 'hotelier' ),
        'fa-stumbleupon' =>esc_html__( 'Stumbleupon', 'hotelier' ),
        'fa-subscript' =>esc_html__( 'Subscript', 'hotelier' ),
        'fa-suitcase' =>esc_html__( 'Suitcase', 'hotelier' ),
        'fa-sun-o' =>esc_html__( 'Sun Outline', 'hotelier' ),
        'fa-superscript' =>esc_html__( 'Superscript', 'hotelier' ),
        'fa-support' =>esc_html__( 'Support', 'hotelier' ),
        'fa-table' =>esc_html__( 'Table', 'hotelier' ),
        'fa-tablet' =>esc_html__( 'Tablet', 'hotelier' ),
        'fa-tachometer' =>esc_html__( 'Tachometer', 'hotelier' ),
        'fa-tag' =>esc_html__( 'Tag', 'hotelier' ),
        'fa-tags' =>esc_html__( 'Tags', 'hotelier' ),
        'fa-tasks' =>esc_html__( 'Tasks', 'hotelier' ),
        'fa-taxi' =>esc_html__( 'Taxi', 'hotelier' ),
        'fa-tencent-weibo' =>esc_html__( 'Tencent Weibo', 'hotelier' ),
        'fa-terminal' =>esc_html__( 'Terminal', 'hotelier' ),
        'fa-text-height' =>esc_html__( 'Text Height', 'hotelier' ),
        'fa-text-width' =>esc_html__( 'Text Width', 'hotelier' ),
        'fa-th-large' =>esc_html__( 'Th Large', 'hotelier' ),
        'fa-th-list' =>esc_html__( 'Th List', 'hotelier' ),
        'fa-th' =>esc_html__( 'Th', 'hotelier' ),
        'fa-thumb-tack' =>esc_html__( 'Thumb Tack', 'hotelier' ),
        'fa-thumbs-down' =>esc_html__( 'Thumbs Down', 'hotelier' ),
        'fa-thumbs-o-down' =>esc_html__( 'Thumbs Outline Down', 'hotelier' ),
        'fa-thumbs-o-up' =>esc_html__( 'Thumbs Outline Up', 'hotelier' ),
        'fa-thumbs-up' =>esc_html__( 'Thumbs Up', 'hotelier' ),
        'fa-ticket' =>esc_html__( 'Ticket', 'hotelier' ),
        'fa-times-circle-o' =>esc_html__( 'Times Circle Outline', 'hotelier' ),
        'fa-times-circle' =>esc_html__( 'Times Circle', 'hotelier' ),
        'fa-times' =>esc_html__( 'Times', 'hotelier' ),
        'fa-tint' =>esc_html__( 'Tint', 'hotelier' ),
        'fa-toggle-down' =>esc_html__( 'Toggle Down', 'hotelier' ),
        'fa-toggle-left' =>esc_html__( 'Toggle Left', 'hotelier' ),
        'fa-toggle-off' =>esc_html__( 'Toggle Outlineff', 'hotelier' ),
        'fa-toggle-on' =>esc_html__( 'Toggle Outlinen', 'hotelier' ),
        'fa-toggle-right' =>esc_html__( 'Toggle Right', 'hotelier' ),
        'fa-toggle-up' =>esc_html__( 'Toggle Up', 'hotelier' ),
        'fa-trash-o' =>esc_html__( 'Trash Outline', 'hotelier' ),
        'fa-trash' =>esc_html__( 'Trash', 'hotelier' ),
        'fa-tree' =>esc_html__( 'Tree', 'hotelier' ),
        'fa-trello' =>esc_html__( 'Trello', 'hotelier' ),
        'fa-trophy' =>esc_html__( 'Trophy', 'hotelier' ),
        'fa-truck' =>esc_html__( 'Truck', 'hotelier' ),
        'fa-try' =>esc_html__( 'Try', 'hotelier' ),
        'fa-tty' =>esc_html__( 'Tty', 'hotelier' ),
        'fa-tumblr-square' =>esc_html__( 'Tumblr Square', 'hotelier' ),
        'fa-tumblr' =>esc_html__( 'Tumblr', 'hotelier' ),
        'fa-turkish-lira' =>esc_html__( 'Turkish Lira', 'hotelier' ),
        'fa-twitch' =>esc_html__( 'Twitch', 'hotelier' ),
        'fa-twitter-square' =>esc_html__( 'Twitter Square', 'hotelier' ),
        'fa-twitter' =>esc_html__( 'Twitter', 'hotelier' ),
        'fa-umbrella' =>esc_html__( 'Umbrella', 'hotelier' ),
        'fa-underline' =>esc_html__( 'Underline', 'hotelier' ),
        'fa-undo' =>esc_html__( 'Undo', 'hotelier' ),
        'fa-university' =>esc_html__( 'University', 'hotelier' ),
        'fa-unlink' =>esc_html__( 'Unlink', 'hotelier' ),
        'fa-unlock-alt' =>esc_html__( 'Unlock Alt', 'hotelier' ),
        'fa-unlock' =>esc_html__( 'Unlock', 'hotelier' ),
        'fa-unsorted' =>esc_html__( 'Unsorted', 'hotelier' ),
        'fa-upload' =>esc_html__( 'Upload', 'hotelier' ),
        'fa-usd' =>esc_html__( 'Usd', 'hotelier' ),
        'fa-user-md' =>esc_html__( 'User Md', 'hotelier' ),
        'fa-user' =>esc_html__( 'User', 'hotelier' ),
        'fa-users' =>esc_html__( 'Users', 'hotelier' ),
        'fa-video-camera' =>esc_html__( 'Video Camera', 'hotelier' ),
        'fa-vimeo-square' =>esc_html__( 'Vimeo Square', 'hotelier' ),
        'fa-vine' =>esc_html__( 'Vine', 'hotelier' ),
        'fa-vk' =>esc_html__( 'Vk', 'hotelier' ),
        'fa-volume-down' =>esc_html__( 'Volume Down', 'hotelier' ),
        'fa-volume-off' =>esc_html__( 'Volume Outlineff', 'hotelier' ),
        'fa-volume-up' =>esc_html__( 'Volume Up', 'hotelier' ),
        'fa-warning' =>esc_html__( 'Warning', 'hotelier' ),
        'fa-wechat' =>esc_html__( 'Wechat', 'hotelier' ),
        'fa-weibo' =>esc_html__( 'Weibo', 'hotelier' ),
        'fa-weixin' =>esc_html__( 'Weixin', 'hotelier' ),
        'fa-wheelchair' =>esc_html__( 'Wheelchair', 'hotelier' ),
        'fa-wifi' =>esc_html__( 'Wifi', 'hotelier' ),
        'fa-windows' =>esc_html__( 'Windows', 'hotelier' ),
        'fa-won' =>esc_html__( 'Won', 'hotelier' ),
        'fa-wordpress' =>esc_html__( 'Wordpress', 'hotelier' ),
        'fa-wrench' =>esc_html__( 'Wrench', 'hotelier' ),
        'fa-xing-square' =>esc_html__( 'Xing Square', 'hotelier' ),
        'fa-xing' =>esc_html__( 'Xing', 'hotelier' ),
        'fa-yahoo' =>esc_html__( 'Yahoo', 'hotelier' ),
        'fa-yelp' =>esc_html__( 'Yelp', 'hotelier' ),
        'fa-yen' =>esc_html__( 'Yen', 'hotelier' ),
        'fa-youtube-play' =>esc_html__( 'Youtube Play', 'hotelier' ),
        'fa-youtube-square' =>esc_html__( 'Youtube Square', 'hotelier' ),
        'fa-youtube' =>esc_html__( 'Youtube', 'hotelier' )
     );
}

/**
 * Data Source - Sliders
 */
function spyropress_get_sliders() {
    
    $sliders = array();
    
    if ( ! post_type_exists( 'slider' ) ) return $sliders;
    
    // get posts
    $args = array(
        'post_type' => 'slider',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'asc'
    );
    $posts = get_posts( $args );
    if ( !empty( $posts ) ) {
        foreach ( $posts as $post ) {
            $sliders[$post->ID] = $post->post_title;
        }
    }

    return $sliders;
}

function spyropress_get_options_social() {
    return array(
        'dribbble' =>esc_html__( 'Dribbble', 'hotelier' ),
        'dropbox' =>esc_html__( 'Dropbox', 'hotelier' ),
        'envelope' =>esc_html__( 'Envelope', 'hotelier' ),
        'facebook' =>esc_html__( 'FaceBook', 'hotelier' ),
        'foursquare' =>esc_html__( 'Foursquare', 'hotelier' ),
        'github' =>esc_html__( 'Github ', 'hotelier' ),
        'google-plus' =>esc_html__( 'Google+', 'hotelier' ),
        'instagram' =>esc_html__( 'Instagram', 'hotelier' ),
        'linkedin' =>esc_html__( 'Linkedin', 'hotelier' ),
        'maxcdn' =>esc_html__( 'Maxcdn', 'hotelier' ),
        'pinterest' =>esc_html__( 'Pinterest', 'hotelier' ),
        'rss' =>esc_html__( 'Rss', 'hotelier' ),
        'skype' =>esc_html__( 'Skype', 'hotelier' ),
        'tumblr' =>esc_html__( 'Tumblr', 'hotelier' ),
        'twitter' =>esc_html__( 'Twitter', 'hotelier' ),
        'vk' =>esc_html__( 'Vk', 'hotelier' ),
        'youtube' =>esc_html__( 'Youtube', 'hotelier' ), 
    );
}