<?php 
/**
 * SpyroPress is a theme framework for professional WordPress theme designing developed by SpyroSol.
 *
 * DON'T HACK ME!! You should NOT modify the SpyroPress theme framework to avoid issues with updates in the future.
 * It's designed to offer cutting edge flexibility - with lots of ways to manipulate output!
 *
 * @package SpyroPress
 */

/**
 * Set Max Content Width
 */
if ( ! isset( $content_width ) )
    $content_width = 726;

if( !function_exists( 'spyropress_content_width' ) ) {
    function spyropress_content_width() {
        if( is_page_template( 'template-full-width.php' ) || is_attachment() ) {
            global $content_width;
            $content_width = 960;
        }
    }
}
add_action( 'template_redirect', 'spyropress_content_width' );

/**
 * Starting SpyroPress Engine
 */
require_once( get_template_directory() . '/framework/spyropress.php' );
require_once( get_template_directory() . '/includes/init.php' ); // Extending theme

require_once( get_template_directory() . '/inc/demo-data.php' );

/**
 * Add theme support for spyropress framework features
 */
add_action( 'after_setup_theme', 'spyropress_theme_setup', 4 );
function spyropress_theme_setup() {

    // Add wordpress features
    add_theme_support( 'automatic-feed-links' );

    // Add post thumbnails (http://codex.wordpress.org/Post_Thumbnails)
    add_theme_support( 'post-thumbnails' );
    
    // Tell the TinyMCE editor to use a custom stylesheet
    add_editor_style( assets_css() . 'editor-style.css' );
    
    // SpyroPress Builder
    add_theme_support( 'spyropress-builder' );
	
	// Custom CSS Editor
    add_theme_support( 'spyropress-ace' );
    
    //Title
    add_theme_support( "title-tag" );
    
    //Custom Header
    $spyropress_defaults = array(
    	'default-image'          => '',
    	'random-default'         => false,
    	'width'                  => 0,
    	'height'                 => 0,
    	'flex-height'            => false,
    	'flex-width'             => false,
    	'default-text-color'     => '',
    	'header-text'            => true,
    	'uploads'                => true,
    	'wp-head-callback'       => '',
    	'admin-head-callback'    => '',
    	'admin-preview-callback' => '',
    );
    add_theme_support( 'custom-header', $spyropress_defaults );
    
    //Custom Background
    $spyropress_defaults = array(
    	'default-color'          => '',
    	'default-image'          => '',
    	'default-repeat'         => '',
    	'default-position-x'     => '',
    	'default-attachment'     => '',
    	'wp-head-callback'       => '_custom_background_cb',
    	'admin-head-callback'    => '',
    	'admin-preview-callback' => ''
    );
    add_theme_support( 'custom-background', $spyropress_defaults );

    // Add post formats (http://codex.wordpress.org/Post_Formats)
    add_theme_support( 'post-formats', array(
        'gallery',
        'image',
        'video'
    ) );

    // Add Components
    add_theme_support( 'spyropress-components', array(
        'bucket',
        'slider',
        'testimonials',
        'page',
        'mega-menu',
        'gallery',
        'room',
        'bootstrap-nav',
        'pagination'
    ) );

    // Add Sliders
    $spyropress_sliders = array(
        'flex' =>esc_html__( 'Flex Slider', 'hotelier' ),
    );
    add_theme_support( 'spyropress-sliders', $spyropress_sliders );

    // Add Menus
    add_theme_support( 'spyropress-core-menus', array(
        'primary' => 'Main',
        'footer' => 'Footer',
        'page-404-one' => '404 Menu One',
        'page-404-two' => '404 Menu Two',
    ) );

    // Add Sidebars
    $sidebars = array(
        /*'primary' => array(
            'name' =>esc_html__( 'Primary', 'hotelier' ),
            'description' =>esc_html__( 'The main (primary) widget area, most often used as a sidebar.','hotelier' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<div class="title-block"><h3 class="title">',
            'after_title' => '</h3></div><div class="cat-detail">'
        ),*/
        'primary' => array(
            'name' =>esc_html__( 'Primary', 'hotelier' ),
            'description' =>esc_html__( 'The main (primary) widget area, most often used as a sidebar.','hotelier' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<div class="title-block"><h3 class="title">',
            'after_title' => '</h3></div>'
        ),
        'footer-1' => array(
            'name' =>esc_html__( 'Footer 1', 'hotelier' ),
            'description' =>esc_html__( 'The Footer most important widget area, most often used as a Footer sidebar.', 'hotelier' ),
            'before_title' => '<h4 class="title">',
            'after_title' => '</h4>'
        ),
        'footer-2' => array(
            'name' =>esc_html__( 'Footer 2', 'hotelier' ),
            'description' =>esc_html__( 'The Footer most important widget area, most often used as a Footer sidebar.', 'hotelier' ),
            'before_title' => '<h4 class="title">',
            'after_title' => '</h4>'
        ),
        'footer-3' => array(
            'name' =>esc_html__( 'Footer 3', 'hotelier' ),
            'description' =>esc_html__( 'The Footer most important widget area, most often used as a Footer sidebar.', 'hotelier' ),
            'before_title' => '<h4 class="title">',
            'after_title' => '</h4>'
        ),
        'footer-4' => array(
            'name' =>esc_html__( 'Footer 4', 'hotelier' ),
            'description' =>esc_html__( 'The Footer most important widget area, most often used as a Footer sidebar.', 'hotelier' ),
            'before_title' => '<h4 class="title">',
            'after_title' => '</h4>'
        ),
    );
    add_theme_support( 'spyropress-core-sidebars', $sidebars );

    // Options
    $spyropress_options = array(
        'theme' => array(
            'page_title' =>esc_html__( 'Theme Options', 'hotelier' ),
            'menu_title' =>esc_html__( 'Theme Options', 'hotelier' ),
            'isactive' => true,
            'hidden' => false
        )
    );
    add_theme_support( 'spyropress-options', $spyropress_options );
}

add_filter( 'dynamic_sidebar_params', 'spyropress_check_sidebar_params' );
function spyropress_check_sidebar_params( $params ) {
    global $wp_registered_widgets;

    $spyropress_settings_getter = $wp_registered_widgets[ $params[0]['widget_id'] ]['callback'][0];
    $spyropress_settings = $spyropress_settings_getter->get_settings();
    $spyropress_settings = $spyropress_settings[ $params[1]['number'] ];

    if ( $params[0][ 'after_widget' ] == '</div></div>' && isset( $spyropress_settings[ 'title' ] ) && empty( $spyropress_settings[ 'title' ] ) )
        $params[0][ 'after_widget' ] = '</div>';

    return $params;
}