<?php
/**
 * Menu Walker class
 */

class Bootstrapwp_Walker_Nav_Menu extends Walker_Nav_Menu {

	private $has_megamenu = false;
    private $columns = 0;
    private $is_column = false;
   
    /**
     * @see Walker::start_el()
     */
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		// Check for Mega Menu
		if( 0 === $depth ) {
            $this->has_megamenu = $item->isMega;
            $this->columns = $item->mega_columns;
        }
        if( 1 === $depth ) {
            $this->is_column = $item->is_mega_column;
        }
        
        // Generate classes for <li>
        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $classes = apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth );

        // MegaMenu
		if( $item->has_children && $depth == 0 ) {
        	if( $this->has_megamenu ) {
        		$classes[] = 'mega_menu';
        	}
        	else {
        		$classes[] = 'dropdown';
        	}
        }
        if ( $item->has_children && $depth > 0 ) {
            $classes[] = ' dropdown-submenu';
        } else if ( $item->has_children && $depth === 0 ) {
            $classes[] = ' dropdown';
        }
        
        
        $class_names = implode( ' ',  $classes );
        $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		// Generate <a> attribute
		$atts = array();
		$atts['title']  = ! empty( $item->attr_title ) ? esc_attr( $item->attr_title ) : '';
		$atts['target'] = ! empty( $item->target )     ? esc_attr( $item->target )     : '';
		$atts['rel']    = ! empty( $item->xfn )        ? esc_attr( $item->xfn )        : '';
		$atts['href']   = ! empty( $item->url )        ? esc_url( $item->url )        : '';
        
        if( $item->has_children ) {
            $atts['data-toggle']    = 'dropdown';
            $atts['data-target']    = '#';
            $atts['class']          = 'dropdown-toggle disabled';
        }
        
        $atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );
        $attributes = spyropress_build_atts( $atts );        

        // html <a>
		$item_output = $args->before;
            $item_output .= '<a' . $attributes . '>';

                $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
				
				// Output Span
				if( $item->description ) {
					$item_output .= ' <span>' . $item->description . '</span>';
				}

            $item_output .= '</a>';
        $item_output .= $args->after;	
        $columns = array( '1' => 'col-md-12 dropdown-box', '2' => 'col-md-6 dropdown-box', '3' => 'col-md-4 dropdown-box', '4' => 'col-md-3 dropdown-box', '6' => 'col-md-2 dropdown-box' );  
         
		// Header of MegaMenu Column
		if( $depth === 1 && $this->has_megamenu && $this->is_column ) {
			
			// Output <li> or <div>
			$output .= '<div class="' . $columns[$this->columns] . '">' . "\n";
			
			// Output header
			$output .= $indent . '<h4>' . apply_filters( 'the_title', $item->title, $item->ID );
			
			// Output Span
			if( $item->description ) {
				$output .= ' <span>' . $item->description . '</span>';
			}
			
			$output .= '</h4>';
			
		}
		else {
			// Output <li>
			$output .= $indent . '<li' . $class_names .'>';
		
			// Output <a>
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}
   	}

 		/**
	 * @see Walker::end_el()
	 */
    function end_el( &$output, $item, $depth = 0, $args = array() ) {
    	
    	if( $depth === 1 && $this->has_megamenu && $this->is_column ) {
    		$output .= "</div>\n";
   		}
   		else {
   			$output .= "</li>\n";
   		}
   	}

   	/**
	 * @see Walker::start_lvl()
	 */
    function start_lvl( &$output, $depth = 0, $args = array() ) {
    	$indent = str_repeat("\t", $depth);
    	// Dropdown <ul> classes
        $classes ='';
        if( 0 == $depth && $this->has_megamenu ){
            $classes = 'dropdown-menu mega-menu';
        }elseif( empty( $this->has_megamenu ) ){
            $classes = 'dropdown-menu';
        }
		$output .= "\n$indent<ul class=\"$classes depth-$depth\" role='menu'>\n";
		
		// Start of Mega Menu Container
		if( 0 === $depth && $this->has_megamenu ) {
			$output .= '<!-- mega-menu-container --><li><div class="row">' . "\n";
		}
   	}

   	/**
	 * @see Walker::end_lvl()
	 */
    function end_lvl( &$output, $depth = 0, $args = array() ) {
    	$indent = str_repeat("\t", $depth);
    	
    	// End of Mega Menu Container
    	if( 0 === $depth && $this->has_megamenu ) {
			$output .= '</div></li><!-- /mega-menu-container -->' . "\n";
		}
		
		$output .= "$indent</ul>\n";
   	}
}