<?php

/**
 * Enqueue scripts and stylesheets
 *
 * @category Core
 * @package SpyroPress
 *
 */
/**
 *  Google Fonts Register StyleSheets
 */
function spyropress_fonts_url() {
    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by Roboto, translate this to 'off'. Do not translate
    * into your own language.
    */
    $roboto = _x( 'on', 'Roboto font: on or off', 'hotelier' );
 
    /* Translators: If there are characters in your language that are not
    * supported by Vollkorn, translate this to 'off'. Do not translate
    * into your own language.
    */
    $vollkorn = _x( 'on', 'Vollkorn font: on or off', 'hotelier' );
 
    if ( 'off' !== $roboto || 'off' !== $vollkorn ) {
        $font_families = array();
 
        if ( 'off' !== $roboto ) {
            $font_families[] = 'Roboto:400,700,500,400italic';
        }
 
        if ( 'off' !== $vollkorn ) {
            $font_families[] = 'Vollkorn:400,400italic,700,700italic';
        }
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}
function spyropress_scripts_styles() {
    wp_enqueue_style( 'google-fonts', spyropress_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'spyropress_scripts_styles' );
/**
 * Register StyleSheets
 */
function spyropress_register_stylesheets() {
    
    // Default stylesheets
    wp_enqueue_style( 'bootstrap', assets_css() . 'bootstrap.css', false, false );
    wp_enqueue_style( 'fonts', assets_css() . 'fonts/fonts.css', false, false );
    wp_enqueue_style( 'font-awesome', assets_css() . 'font-awesome/css/font-awesome.css', false, false );
    wp_enqueue_style( 'isotope', assets_js() . 'isotope/isotope.css', false, false );
    wp_enqueue_style( 'flexslider', assets_js() . 'flexslider/flexslider.css', false, false );
    wp_enqueue_style( 'owl-carousel', assets_js() . 'owl-carousel/owl.carousel.css', false, false );
    wp_enqueue_style( 'owl-theme', assets_js() . 'owl-carousel/owl.theme.css', false, false );
    wp_enqueue_style( 'sidebar-calendar', assets_css() . 'sidebar-calendar/css/style.css', false, false );
    wp_enqueue_style( 'selectric', assets_js() . 'selectric-selectbox/selectric.css', false, false );
    wp_enqueue_style( 'datetimepicker', assets_js() . 'datetimepicker/bootstrap-datetimepicker.css', false, false );
    wp_enqueue_style( 'megafish', assets_js() . 'superfish/css/megafish.css', false, false );
    wp_enqueue_style( 'superfish', assets_js() . 'superfish/css/superfish.css', false, false );
    wp_enqueue_style( 'stepper', assets_js() . 'stepper/jquery.fs.stepper.css', false, false );
    wp_enqueue_style( 'prettyphoto', assets_css() . 'prettyphoto.css', false, false );
    wp_enqueue_style( 'style', assets_css() . 'style.css', false, false );
    
    // Dynamic StyleSheet
    if ( file_exists( dynamic_css_path() . 'dynamic.css' ) )
        wp_enqueue_style( 'dynamic', dynamic_css_url() . 'dynamic.css', false, '2.0.0' );

    // Builder StyleSheet
    if ( file_exists( dynamic_css_path() . 'builder.css' ) )
        wp_enqueue_style( 'builder', dynamic_css_url() . 'builder.css', false, '2.0.0' );

    // modernizr
    wp_enqueue_script( 'spyropress-jquery', assets_js() .  'jquery.min.js', false, false );
}

/**
 * Enqueque Scripts
 */
function spyropress_register_scripts() {

    /**
     * Register Scripts
     */
    // threaded comments
    if ( is_single() && comments_open() && get_option( 'thread_comments' ) )
        wp_enqueue_script( 'comment-reply' );

    // Plugins
    wp_register_script( 'jquery-bootstrap', assets_js() . 'bootstrap.min.js', false, false, true );
    wp_register_script( 'jquery-easing', assets_js() . 'jquery.easing.min.js', false, false, true );
    wp_register_script( 'jquery-hoverIntent', assets_js() . 'superfish/js/hoverIntent.js', false, false, true );
    wp_register_script( 'jquery-superfish', assets_js() . 'superfish/js/superfish.js', false, false, true );
    wp_register_script( 'jquery-flexslider', assets_js() . 'flexslider/jquery.flexslider.js', false, false, true );
    wp_register_script( 'jquery-carousel', assets_js() . 'owl-carousel/owl.carousel.min.js', false, false, true );
    wp_register_script( 'jquery-selectric', assets_js() . 'selectric-selectbox/jquery.selectric.js', false, false, true );
    wp_register_script( 'jquery-moment', assets_js() . 'datetimepicker/moment.min.js', false, false, true );
    wp_register_script( 'jquery-datetimepicker', assets_js() . 'datetimepicker/bootstrap-datetimepicker.js', false, false, true );
    wp_register_script( 'jquery-isotope', assets_js() . 'isotope/isotope.pkgd.js', false, false, true );
    wp_register_script( 'jquery-stepper', assets_js() . 'stepper/jquery.fs.stepper.min.js', false, false, true );
    wp_register_script( 'jquery-prettyphoto', assets_js() . 'jquery.prettyphoto.js', false, false, true ); 
    wp_register_script( 'gmap-api', 'https://maps.googleapis.com/maps/api/js?key=AIzaSyDW40y4kdsjsz714OVTvrw7woVCpD8EbLE', false, false, true );
    wp_register_script( 'jquery-gmap', assets_js() . 'gmap/gmaps.js', false, false, true );
    
    $spyropress_deps = array(
        'jquery-bootstrap',
        'jquery-easing',
        'jquery-hoverIntent',
        'jquery-superfish',
        'jquery-flexslider',
        'jquery-carousel',
        'jquery-selectric',
        'jquery-moment',
        'jquery-datetimepicker',
        'jquery-isotope',
        'jquery-stepper',
        'gmap-api',
        'jquery-gmap',
        'jquery-prettyphoto'
    );
    // custom scripts
    wp_register_script( 'custom-script', assets_js() . 'main.js', $spyropress_deps, false, true );

    /**
     * Enqueue All
     */
    wp_enqueue_script( 'custom-script' );
    
    $spyropress_settings = array(
        'site_assets' => assets(),
        'ajax_url' => admin_url( 'admin-ajax.php' ),
        'twitter_feed' => admin_url( 'admin-ajax.php?action=spyropress_twitter_tweets' ),
    );
    wp_localize_script( 'jquery-easing', 'theme_settings', $spyropress_settings );
}

function spyropress_conditional_scripts() {

    $content = '<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
	<!-- WARNING: Respond.js doesn\'t work if you view the page via file:// -->
		<!--[if lt IE 9]>
		<script src="'. assets_js() .'html5shiv.js"></script>
		<script src="'. assets_js() .'respond.min.js"></script>
	<![endif]-->';

    echo get_relative_url( $content );
}